from itertools import product
from pathlib import Path
from sys import stderr

from crossplain import *
from crossplain.directives import *

redirect = lambda to: return_(301, to)

REDIRECTIONS = {
    "spotify": "https://open.spotify.com/artist/6tUc6r8aNeiiT1mElcnMx9?si=yCM83yThR4WVCkC4Kd5p7Q",
    "twitter": "https://twitter.com/ewen_lbh",
    "github": "https://github.com/ewen-lbh",
    "youtube": "https://youtube.com/c/ewen-lbh",
    "deezer": "https://deezer.page.link/keZbR1mRNyp5ba6W9",
    "mail": "mailto:hey@ewen.works",
}

local_conf = parse("etc/nginx/nginx.conf")["local.conf"]

for name in ("fr.ewen.works", "en.ewen.works", "ewen.works", "schoolsyst.com"):
    server = local_conf.server(name, 443)
    server.set_location("/", try_files("$uri", "$uri.html", "$uri/", "=404"))
    server.set_error_page(404, "404.html")
    server.set_error_page(500, "500.html")

for name in ("assets.ewen.works", "media.ewen.works"):
    server = local_conf.server(name, 443)
    server.set_header("Access-Control-Allow-Origin", "*"),
    server.set_location(
            "/",
            autoindex(),
            autoindex_format("xml"),
            charset("UTF-8"),
            xslt_stylesheet("/home/user-data/www/superbindex.xslt"),
            # types(
            #     {
            #         "text/plain": [
            #             "indentex",
            #             "tex",
            #             "txt",
            #             "json",
            #             "yaml",
            #             "yml",
            #             "toml",
            #         ]
            #     }
            # ),
        )
    


for prefix in ("fr.", "en.", ""):
    server = local_conf.server(prefix + "ewen.works", 443)
    for keyword, url in REDIRECTIONS.items():
        server.set_location(f"/to/{keyword}", redirect(url))

local_conf.server("ewen.works", 443).set_location(
    "/",
    if_(
        "$http_accept_language ~* ^fr",
        redirect("https://fr.ewen.works$request_uri"),
    ),
    redirect("https://en.ewen.works$request_uri"),
)


sys.stdout.write(local_conf.build())
